Package: bsvars
Type: Package
Title: Bayesian Estimation of Structural Vector Autoregressive Models
Description: Provides fast and efficient procedures for Bayesian analysis of Structural Vector Autoregressions. This package estimates a wide range of models, including homo-, heteroskedastic, and non-normal specifications. Structural models can be identified by adjustable exclusion restrictions, time-varying volatility, or non-normality. They all include a flexible three-level equation-specific local-global hierarchical prior distribution for the estimated level of shrinkage for autoregressive and structural parameters. Additionally, the package facilitates predictive and structural analyses such as impulse responses, forecast error variance and historical decompositions, forecasting, verification of heteroskedasticity, non-normality, and hypotheses on autoregressive parameters, as well as analyses of structural shocks, volatilities, and fitted values. Beautiful plots, informative summary functions, and extensive documentation including the vignette by Woźniak (2024) <doi:10.48550/arXiv.2410.15090> complement all this. The implemented techniques align closely with those presented in Lütkepohl, Shang, Uzeda, & Woźniak (2024) <doi:10.48550/arXiv.2404.11057>, Lütkepohl & Woźniak (2020) <doi:10.1016/j.jedc.2020.103862>, and Song & Woźniak (2021) <doi:10.1093/acrefore/9780190625979.013.174>. The 'bsvars' package is aligned regarding objects, workflows, and code structure with the R package 'bsvarSIGNs' by Wang & Woźniak (2024) <doi:10.32614/CRAN.package.bsvarSIGNs>, and they constitute an integrated toolset.
Version: 3.2
Date: 2024-10-24
Authors@R: person("Tomasz", "Woźniak", , "wozniak.tom@pm.me", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-2212-2378"))
Maintainer: Tomasz Woźniak <wozniak.tom@pm.me>
Imports: Rcpp (>= 1.0.7), RcppProgress (>= 0.1), RcppTN, GIGrvg, R6,
        stochvol
Suggests: knitr, tinytest
LinkingTo: Rcpp, RcppProgress, RcppArmadillo, RcppTN
License: GPL (>= 3)
URL: https://bsvars.org/bsvars/
BugReports: https://github.com/bsvars/bsvars/issues
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 7.3.2
Author: Tomasz Woźniak [aut, cre] (<https://orcid.org/0000-0003-2212-2378>)
Built: R 4.4.1; aarch64-apple-darwin23.2.0; 2024-11-04 03:20:12 UTC; unix
