# Generated by roxygen2: do not edit by hand

S3method(compute_conditional_sd,PosteriorBSVAR)
S3method(compute_conditional_sd,PosteriorBSVARMIX)
S3method(compute_conditional_sd,PosteriorBSVARMSH)
S3method(compute_conditional_sd,PosteriorBSVARSV)
S3method(compute_conditional_sd,PosteriorBSVART)
S3method(compute_fitted_values,PosteriorBSVAR)
S3method(compute_fitted_values,PosteriorBSVARMIX)
S3method(compute_fitted_values,PosteriorBSVARMSH)
S3method(compute_fitted_values,PosteriorBSVARSV)
S3method(compute_fitted_values,PosteriorBSVART)
S3method(compute_historical_decompositions,PosteriorBSVAR)
S3method(compute_historical_decompositions,PosteriorBSVARMIX)
S3method(compute_historical_decompositions,PosteriorBSVARMSH)
S3method(compute_historical_decompositions,PosteriorBSVARSV)
S3method(compute_historical_decompositions,PosteriorBSVART)
S3method(compute_impulse_responses,PosteriorBSVAR)
S3method(compute_impulse_responses,PosteriorBSVARMIX)
S3method(compute_impulse_responses,PosteriorBSVARMSH)
S3method(compute_impulse_responses,PosteriorBSVARSV)
S3method(compute_impulse_responses,PosteriorBSVART)
S3method(compute_regime_probabilities,PosteriorBSVARMIX)
S3method(compute_regime_probabilities,PosteriorBSVARMSH)
S3method(compute_structural_shocks,PosteriorBSVAR)
S3method(compute_structural_shocks,PosteriorBSVARMIX)
S3method(compute_structural_shocks,PosteriorBSVARMSH)
S3method(compute_structural_shocks,PosteriorBSVARSV)
S3method(compute_structural_shocks,PosteriorBSVART)
S3method(compute_variance_decompositions,PosteriorBSVAR)
S3method(compute_variance_decompositions,PosteriorBSVARMIX)
S3method(compute_variance_decompositions,PosteriorBSVARMSH)
S3method(compute_variance_decompositions,PosteriorBSVARSV)
S3method(compute_variance_decompositions,PosteriorBSVART)
S3method(estimate,BSVAR)
S3method(estimate,BSVARMIX)
S3method(estimate,BSVARMSH)
S3method(estimate,BSVARSV)
S3method(estimate,BSVART)
S3method(estimate,PosteriorBSVAR)
S3method(estimate,PosteriorBSVARMIX)
S3method(estimate,PosteriorBSVARMSH)
S3method(estimate,PosteriorBSVARSV)
S3method(estimate,PosteriorBSVART)
S3method(forecast,PosteriorBSVAR)
S3method(forecast,PosteriorBSVARMIX)
S3method(forecast,PosteriorBSVARMSH)
S3method(forecast,PosteriorBSVARSV)
S3method(forecast,PosteriorBSVART)
S3method(plot,Forecasts)
S3method(plot,PosteriorFEVD)
S3method(plot,PosteriorFitted)
S3method(plot,PosteriorHD)
S3method(plot,PosteriorIR)
S3method(plot,PosteriorRegimePr)
S3method(plot,PosteriorShocks)
S3method(plot,PosteriorSigma)
S3method(summary,Forecasts)
S3method(summary,PosteriorBSVAR)
S3method(summary,PosteriorBSVARMIX)
S3method(summary,PosteriorBSVARMSH)
S3method(summary,PosteriorBSVARSV)
S3method(summary,PosteriorBSVART)
S3method(summary,PosteriorFEVD)
S3method(summary,PosteriorFitted)
S3method(summary,PosteriorHD)
S3method(summary,PosteriorIR)
S3method(summary,PosteriorRegimePr)
S3method(summary,PosteriorShocks)
S3method(summary,PosteriorSigma)
S3method(summary,SDDRautoregression)
S3method(summary,SDDRidMIX)
S3method(summary,SDDRidMSH)
S3method(summary,SDDRidSV)
S3method(summary,SDDRidT)
S3method(summary,SDDRvolatility)
S3method(verify_autoregression,PosteriorBSVAR)
S3method(verify_autoregression,PosteriorBSVARMIX)
S3method(verify_autoregression,PosteriorBSVARMSH)
S3method(verify_autoregression,PosteriorBSVARSV)
S3method(verify_autoregression,PosteriorBSVART)
S3method(verify_identification,PosteriorBSVAR)
S3method(verify_identification,PosteriorBSVARMIX)
S3method(verify_identification,PosteriorBSVARMSH)
S3method(verify_identification,PosteriorBSVARSV)
S3method(verify_identification,PosteriorBSVART)
S3method(verify_volatility,PosteriorBSVAR)
S3method(verify_volatility,PosteriorBSVARMIX)
S3method(verify_volatility,PosteriorBSVARMSH)
S3method(verify_volatility,PosteriorBSVARSV)
export(compute_conditional_sd)
export(compute_fitted_values)
export(compute_historical_decompositions)
export(compute_impulse_responses)
export(compute_regime_probabilities)
export(compute_structural_shocks)
export(compute_variance_decompositions)
export(estimate)
export(forecast)
export(normalise_posterior)
export(plot_ribbon)
export(specify_bsvar)
export(specify_bsvar_mix)
export(specify_bsvar_msh)
export(specify_bsvar_sv)
export(specify_bsvar_t)
export(specify_data_matrices)
export(specify_identification_bsvars)
export(specify_posterior_bsvar)
export(specify_posterior_bsvar_mix)
export(specify_posterior_bsvar_msh)
export(specify_posterior_bsvar_sv)
export(specify_posterior_bsvar_t)
export(specify_prior_bsvar)
export(specify_prior_bsvar_mix)
export(specify_prior_bsvar_msh)
export(specify_prior_bsvar_sv)
export(specify_prior_bsvar_t)
export(specify_starting_values_bsvar)
export(specify_starting_values_bsvar_mix)
export(specify_starting_values_bsvar_msh)
export(specify_starting_values_bsvar_sv)
export(specify_starting_values_bsvar_t)
export(verify_autoregression)
export(verify_identification)
export(verify_volatility)
import(RcppProgress)
importFrom(GIGrvg,rgig)
importFrom(R6,R6Class)
importFrom(Rcpp,sourceCpp)
importFrom(RcppTN,rtn)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,polygon)
importFrom(stats,density)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stochvol,svsample_fast_cpp)
importFrom(utils,tail)
useDynLib(bsvars, .registration = TRUE)
